/*
 * ecpTimestamp.js
 *
 * ecpTimestamp.js is a JavaScript class with a set of functions to insert
 * timestamp and user name in to the CCM_TEXT and CCM_EXTENDED_TEXT control.
 *
 */

function EcpTimestamp(){}

EcpTimestamp.saveCaret = function(elem)
{
	if (elem.isTextEdit)
	{
		elem.caretPos = document.selection.createRange();
	}	
};


EcpTimestamp.insertAtCaretIE = function(elem, text)
{
	if (elem.isTextEdit)
	{
		if (!elem.caretPos)
		{
			elem.value = elem.value + text;
			return;
		}

		var caretPos = elem.caretPos;
		caretPos.text = text;
		caretPos.select();
	}
};

EcpTimestamp.insertAtCaretFF = function(elem, text)
{
	var startPos = elem.selectionStart; 
	var endPos = elem.selectionEnd; 
	elem.value = elem.value.substring(0, startPos) + text + elem.value.substring(endPos, elem.value.length);
};


/*
 * Converts the given year, month, day, hours, minutes and seconds to 
 * the given date format.
 */
EcpTimestamp.dateFormatter = function(dateFormat, year, month, day, hours, minutes, seconds)
{
	String.prototype.endsWith = function(str)
	{
		return (this.match(str + "$") == str);
	}
	
	var localDateFormat = dateFormat;
	var amPm = '';
	
	if (localDateFormat.endsWith('a'))
	{
		amPm = "AM";		
		if (hours > 11) 
		{ 
			amPm = "PM";        
		}
		if (hours > 12) 
		{
			hours = hours - 12; 
		}
		if (hours == 0) 
		{ 
			hours = 12;
		}
	}	
	
	var doubleMonth = month;;
	var doubleDay = day;;
	var doubleHours = hours;
	var doubleMinutes = minutes;
	var doubleSeconds = seconds;
	
	if (month <= 9)
	{
		doubleMonth = "0" + month;
	}
	if (day <= 9)
	{ 
		doubleDay = "0" + day;
	}
	if (hours <= 9)
	{ 
		doubleHours = "0" + hours;
	}
	if (minutes <= 9)
	{ 
		doubleMinutes = "0" + minutes;
	}
	if (seconds <= 9)
	{ 
		doubleSeconds = "0" + seconds;
	}
	
	localDateFormat = localDateFormat.replace(/yyyy/, year);
	localDateFormat = localDateFormat.replace(/MM/, doubleMonth);
	localDateFormat = localDateFormat.replace(/dd/, doubleDay);
	localDateFormat = localDateFormat.replace(/HH/, doubleHours);
	localDateFormat = localDateFormat.replace(/H/, hours);
	localDateFormat = localDateFormat.replace(/hh/, doubleHours);
	localDateFormat = localDateFormat.replace(/h/, hours);
	localDateFormat = localDateFormat.replace(/mm/, doubleMinutes);
	localDateFormat = localDateFormat.replace(/m/, minutes);
	localDateFormat = localDateFormat.replace(/ss/, doubleSeconds);
	localDateFormat = localDateFormat.replace(/s/, seconds);
	localDateFormat = localDateFormat.replace(/a/, amPm);
	localDateFormat = localDateFormat.replace(/Z/, getTimeZone());
	localDateFormat = localDateFormat.replace(/'T'/, "T");

	return localDateFormat;
};

EcpTimestamp.timeStampOnClick = function(attribId, userName, submitDateFormat, isExtendedText)
{
	var currentDate = new Date();
	var formattedDate = EcpTimestamp.dateFormatter
	(
		submitDateFormat, 
		currentDate.getFullYear().toString(), 
		currentDate.getMonth() + 1, 
		currentDate.getDate(), 
		currentDate.getHours(), 
		currentDate.getMinutes(), 
		currentDate.getSeconds()
	);
	
	var stampText = formattedDate + ' ' + userName + ' (' + user + '):';
	var attributeElement = document.getElementById(attribId);
	
	if (isExtendedText)
	{
		// To put the timestamp in extended text, need to use command "inserthtml"
		// so that text can be inserted at the cursor location.
		var refNode = dijit.byId(attribId);
		refNode.focus();
		
		if (refNode.queryCommandAvailable("inserthtml")) 
		{
			refNode.execCommand("inserthtml", stampText);
		}
		else
		{
			alert("Command not available");
		}
	}
	else if (dojo.isIE)
	{
		EcpTimestamp.insertAtCaretIE(attributeElement, stampText);
	}
	else
	{
		EcpTimestamp.insertAtCaretFF(attributeElement, stampText);
	}
};
